@@ -1,21 +1,10 @@
 /*******************************************************************
 * bugzillalib.cpp
-* Copyright  2009, 2011  Dario Andres Rodriguez <andresbajotierra@gmail.com>
-* Copyright  2012  George Kiagiadakis <kiagiadakis.george@gmail.com>
-* Copyright  2019  Harald Sitter <sitter@kde.org>
+* SPDX-FileCopyrightText: 2009, 2011 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* SPDX-FileCopyrightText: 2012 George Kiagiadakis <kiagiadakis.george@gmail.com>
+* SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-or-later
 *
 ******************************************************************/
 
@@ -139,11 +128,7 @@ void BugzillaManager::setFeaturesForVersion(const QString& version)
     // the change should actually be implemented.
 
     const int nVersionParts = 3;
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList digits = version.split(QRegularExpression(QStringLiteral("[._-]")), QString::SkipEmptyParts);
-#else
     QStringList digits = version.split(QRegularExpression(QStringLiteral("[._-]")), Qt::SkipEmptyParts);
-#endif
     while (digits.count() < nVersionParts) {
         digits << QLatin1String("0");
     }
