@@ -1,19 +1,8 @@
 /*******************************************************************
 * productmapping.cpp
-* Copyright 2009    Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-or-later
 *
 ******************************************************************/
 
@@ -57,16 +46,12 @@ void ProductMapping::map(const QString & appName)
 
 void ProductMapping::mapUsingInternalFile(const QString & appName)
 {
-    KConfig mappingsFile(QString::fromLatin1("mappings"), KConfig::NoGlobals, QStandardPaths::DataLocation);
+    KConfig mappingsFile(QString::fromLatin1("mappings"), KConfig::NoGlobals, QStandardPaths::AppDataLocation);
     const KConfigGroup mappings = mappingsFile.group("Mappings");
     if (mappings.hasKey(appName)) {
         QString mappingString = mappings.readEntry(appName);
         if (!mappingString.isEmpty()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            QStringList list = mappingString.split(QLatin1Char('|'), QString::SkipEmptyParts);
-#else
             QStringList list = mappingString.split(QLatin1Char('|'), Qt::SkipEmptyParts);
-#endif
             if (list.count()==2) {
                 m_bugzillaProduct = list.at(0);
                 m_bugzillaComponent = list.at(1);
@@ -86,7 +71,7 @@ void ProductMapping::getRelatedProductsUsingInternalFile(const QString & bugzill
     //ProductGroup ->  kontact=kdepim
     //Groups -> kdepim=kontact|kmail|korganizer|akonadi|pimlibs..etc
 
-    KConfig mappingsFile(QString::fromLatin1("mappings"), KConfig::NoGlobals, QStandardPaths::DataLocation);
+    KConfig mappingsFile(QString::fromLatin1("mappings"), KConfig::NoGlobals, QStandardPaths::AppDataLocation);
     const KConfigGroup productGroup = mappingsFile.group("ProductGroup");
 
     //Get groups of the application
@@ -98,11 +83,7 @@ void ProductMapping::getRelatedProductsUsingInternalFile(const QString & bugzill
                             "(or there was an error when reading)";
             return;
         }
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        groups = group.split(QLatin1Char('|'), QString::SkipEmptyParts);
-#else
         groups = group.split(QLatin1Char('|'), Qt::SkipEmptyParts);
-#endif
     }
 
     //All KDE apps use the KDE Platform (basic libs)
@@ -117,11 +98,7 @@ void ProductMapping::getRelatedProductsUsingInternalFile(const QString & bugzill
         if (bzGroups.hasKey(group)) {
             QString bzGroup = bzGroups.readEntry(group);
             if (!bzGroup.isEmpty()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                QStringList relatedGroups = bzGroup.split(QLatin1Char('|'), QString::SkipEmptyParts);
-#else
                 QStringList relatedGroups = bzGroup.split(QLatin1Char('|'), Qt::SkipEmptyParts);
-#endif
                 if (relatedGroups.size()>0) {
                     m_relatedBugzillaProducts.append(relatedGroups);
                 }
