@@ -1,20 +1,9 @@
 /*******************************************************************
 * reportassistantpages_base.cpp
-* Copyright 2009    Dario Andres Rodriguez <andresbajotierra@gmail.com>
-* Copyright 2009    A. L. Spehr <spehr@kde.org>
+* SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* SPDX-FileCopyrightText: 2009 A. L. Spehr <spehr@kde.org>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-or-later
 *
 ******************************************************************/
 
@@ -146,9 +135,9 @@ BugAwarenessPage::BugAwarenessPage(ReportAssistantDialog * parent)
                                      "What I was doing when the application \"%1\" crashed",
                                          DrKonqi::crashedApplication()->name()));
 
-    connect(ui.m_rememberGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &BugAwarenessPage::updateCheckBoxes);
+    connect(ui.m_rememberGroup, &QButtonGroup::idClicked, this, &BugAwarenessPage::updateCheckBoxes);
     // Also listen to toggle so radio buttons are covered.
-    connect(ui.m_rememberGroup, static_cast<void (QButtonGroup::*)(int, bool)>(&QButtonGroup::buttonToggled), this, &BugAwarenessPage::updateCheckBoxes);
+    connect(ui.m_rememberGroup, &QButtonGroup::idClicked, this, &BugAwarenessPage::updateCheckBoxes);
 
     ui.m_appSpecificDetailsExamplesWidget->setVisible(
                 reportInterface()->appDetailsExamples()->hasExamples());
