@@ -1,20 +1,9 @@
 /*******************************************************************
 * reportassistantpages_bugzilla.cpp
-* Copyright 2009, 2010, 2011    Dario Andres Rodriguez <andresbajotierra@gmail.com>
-* Copyright 2019 Harald Sitter <sitter@kde.org>
+* SPDX-FileCopyrightText: 2009, 2010, 2011 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-or-later
 *
 ******************************************************************/
 
@@ -366,7 +355,7 @@ BugzillaInformationPage::BugzillaInformationPage(ReportAssistantDialog * parent)
                                          "Retry"),
                                    ui.m_messageWidget);
     connect(retryAction, &QAction::triggered,
-            this, [this, retryAction]{
+            this, [this]{
         ui.m_messageWidget->animatedHide();
         loadDistroCombo();
     });
@@ -424,6 +413,14 @@ void BugzillaInformationPage::checkTexts()
     ui.m_titleEdit->setVisible(showTitle);
     ui.m_titleLabel->setVisible(showTitle);
 
+    // Force focus on the first input field for ease of use.
+    // https://bugs.kde.org/show_bug.cgi?id=428350
+    if (showTitle) {
+        ui.m_titleEdit->setFocus();
+    } else {
+        ui.m_detailsEdit->setFocus();
+    }
+
     bool ok = !((ui.m_titleEdit->isVisible() && ui.m_titleEdit->text().isEmpty())
         || ui.m_detailsEdit->toPlainText().isEmpty());
 
