@@ -1,20 +1,9 @@
 /*******************************************************************
 * reportassistantpages_bugzilla_duplicates.cpp
-* Copyright 2009    Dario Andres Rodriguez <andresbajotierra@gmail.com>
-* Copyright 2019    Harald Sitter <sitter@kde.org>
+* SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-or-later
 *
 ******************************************************************/
 
@@ -1010,9 +999,9 @@ BugzillaReportConfirmationDialog::BugzillaReportConfirmationDialog(int bugNumber
     connect(ui.buttonGroupProceed, SIGNAL(buttonClicked(int)), this, SLOT(checkProceed()));
     connect(ui.buttonGroupProceedQuestion, SIGNAL(buttonClicked(int)), this, SLOT(checkProceed()));
     // Also listen to toggle so radio buttons are covered.
-    connect(ui.buttonGroupProceed, static_cast<void (QButtonGroup::*)(int, bool)>(&QButtonGroup::buttonToggled),
+    connect(ui.buttonGroupProceed, &QButtonGroup::idClicked,
             this, &BugzillaReportConfirmationDialog::checkProceed);
-    connect(ui.buttonGroupProceedQuestion, static_cast<void (QButtonGroup::*)(int, bool)>(&QButtonGroup::buttonToggled),
+    connect(ui.buttonGroupProceedQuestion, &QButtonGroup::idClicked,
             this, &BugzillaReportConfirmationDialog::checkProceed);
 
     if (!m_showProceedQuestion) {
