@@ -1,20 +1,9 @@
 /*******************************************************************
 * reportinterface.cpp
-* Copyright 2009,2010, 2011    Dario Andres Rodriguez <andresbajotierra@gmail.com>
-* Copyright 2009    George Kiagiadakis <gkiagia@users.sourceforge.net>
+* SPDX-FileCopyrightText: 2009, 2010, 2011 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* SPDX-FileCopyrightText: 2009 George Kiagiadakis <gkiagia@users.sourceforge.net>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-or-later
 *
 ******************************************************************/
 
@@ -23,6 +12,7 @@
 #include <KLocalizedString>
 
 #include "drkonqi.h"
+#include "config-drkonqi.h"
 #include "bugzillalib.h"
 #include "productmapping.h"
 #include "systeminformation.h"
@@ -160,7 +150,8 @@ QString ReportInterface::generateReportFullText(DrKonqiStamp stamp, Backtrace in
     report.append(QStringLiteral("Frameworks Version: %1\n").arg(sysInfo->frameworksVersion()));
 
     report.append(QStringLiteral("Operating System: %1\n").arg(sysInfo->operatingSystem()));
-    report.append(QStringLiteral("Windowing system: %1\n").arg(sysInfo->windowSystem()));
+    report.append(QStringLiteral("Windowing System: %1\n").arg(sysInfo->windowSystem()));
+    report.append(QStringLiteral("Drkonqi Version: %1\n").arg(QString::fromLatin1(PROJECT_VERSION)));
 
     //LSB output or manually selected distro
     if ( !sysInfo->distributionPrettyName().isEmpty() ) {
@@ -186,15 +177,20 @@ QString ReportInterface::generateReportFullText(DrKonqiStamp stamp, Backtrace in
         report.append(QLatin1String("\n\n"));
     }
 
-    //Crash reproducibility (only if useful)
-    if (m_reproducible !=  ReproducibleUnsure) {
-        if (m_reproducible == ReproducibleEverytime) {
-            report.append(QStringLiteral("The crash can be reproduced every time.\n\n"));
-        } else if (m_reproducible == ReproducibleSometimes) {
-            report.append(QStringLiteral("The crash can be reproduced sometimes.\n\n"));
-        } else if (m_reproducible == ReproducibleNever) {
-            report.append(QStringLiteral("The crash does not seem to be reproducible.\n\n"));
-        }
+    // Crash reproducibility
+    switch (m_reproducible) {
+    case ReproducibleUnsure:
+        report.append(QStringLiteral("The reporter is unsure if this crash is reproducible.\n\n"));
+        break;
+    case ReproducibleNever:
+        report.append(QStringLiteral("The crash does not seem to be reproducible.\n\n"));
+        break;
+    case ReproducibleSometimes:
+        report.append(QStringLiteral("The crash can be reproduced sometimes.\n\n"));
+        break;
+    case ReproducibleEverytime:
+        report.append(QStringLiteral("The crash can be reproduced every time.\n\n"));
+        break;
     }
 
     //Backtrace
