@@ -1,18 +1,7 @@
 /*
-    Copyright (C) 2009  George Kiagiadakis <gkiagia@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2009 George Kiagiadakis <gkiagia@users.sourceforge.net>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "debugger.h"
 
@@ -76,11 +65,7 @@ QString Debugger::tryExec() const
 QStringList Debugger::supportedBackends() const
 {
     return isValid() ? m_config->group("General").readEntry("Backends")
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                                   .split(QLatin1Char('|'), QString::SkipEmptyParts) : QStringList();
-#else
                                    .split(QLatin1Char('|'), Qt::SkipEmptyParts) : QStringList();
-#endif
 }
 
 void Debugger::setUsedBackend(const QString & backendName)
