@@ -1,19 +1,8 @@
 /*******************************************************************
 * drkonqidialog.cpp
-* Copyright 2009    Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-or-later
 *
 ******************************************************************/
 
@@ -80,7 +69,6 @@ DrKonqiDialog::DrKonqiDialog(QWidget * parent) :
     buildDialogButtons();
 
     KWindowConfig::restoreWindowSize(windowHandle(), config);
-    setLayout(l);
 
     // Force a 16:9 ratio for nice appearance by default.
     QSize aspect(16, 9);
